@@ -24,6 +24,7 @@ class DescribeRestoreSummaryRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'HBase', '2019-01-01', 'DescribeRestoreSummary','hbase')
+		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -34,4 +35,16 @@ class DescribeRestoreSummaryRequest(RpcRequest):
 		return self.get_query_params().get('ClusterId')
 
 	def set_ClusterId(self,ClusterId):
-		self.add_query_param('ClusterId',ClusterId)
\ No newline at end of file
+		self.add_query_param('ClusterId',ClusterId)
+
+	def get_PageNumber(self):
+		return self.get_query_params().get('PageNumber')
+
+	def set_PageNumber(self,PageNumber):
+		self.add_query_param('PageNumber',PageNumber)
+
+	def get_PageSize(self):
+		return self.get_query_params().get('PageSize')
+
+	def set_PageSize(self,PageSize):
+		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
